import {Component, Input} from '@angular/core'
import {Recipe} from '../../../shared/model/recipe.model'
import {SubscribingComponent} from '../../../shared/components/subscribing.component'
import {ActivatedRoute, Router} from '@angular/router'
import {RecipeImageService} from '../../services/recipe-image.service'
import {ErrorService} from '../../../shared/service/error.service'
import {getImageUrl, openJpg} from '../../../shared/utils/utils'
import {RecipeService} from "../../services/recipe.service";

@Component({
  selector: 'cre-images-editor',
  templateUrl: './images-editor.component.html',
  styleUrls: ['./images-editor.component.sass']
})
export class ImagesEditorComponent extends SubscribingComponent {
  @Input() recipe: Recipe
  @Input() editionMode = false

  imagesIds: string[] = []

  constructor(
    private recipeImageService: RecipeImageService,
    private recipeService: RecipeService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit() {
    super.ngOnInit()

    this.subscribe(
      this.recipeService.getImagesIds(this.recipe.id),
      imagesIds => this.imagesIds = imagesIds ?? []
    )
  }

  submit(event) {
    const image = event.target.files[0]
    this.subscribe(
      this.recipeImageService.save(image, this.recipe.id),
      imageId => this.imagesIds.push(imageId)
    )
  }

  getImageUrl(id: string): string {
    return getImageUrl(this.getImagePath(id))
  }

  openImage(id: string) {
    openJpg(this.getImagePath(id))
  }

  delete(url: string) {
    this.subscribe(
      this.recipeImageService.delete(url, this.recipe.id),
      () => this.removeUrl(url)
    )
  }

  private removeUrl(url: string) {
    this.imagesIds = this.imagesIds.filter(u => u !== url)
  }

  private getImagePath(id: string): string {
    return `recipes/${this.recipe.id}/${id}`
  }
}
